/**************************************************************************************/
/**                                                                                \n**/
/**                u  p  d  a  t  e  _  f a s t  .  c                              \n**/
/**                                                                                \n**/
/**     C implementation of LPJmL                                                  \n**/
/**                                                                                \n**/
/**     Function of fast time step update of individual grid cell (for FMS)        \n**/
/**                                                                                \n**/
/** (C) Potsdam Institute for Climate Impact Research (PIK), see COPYRIGHT file    \n**/
/** authors, and contributors see AUTHORS file                                     \n**/
/** This file is part of LPJmL and licensed under GNU AGPL Version 3               \n**/
/** or later. See LICENSE file or go to http://www.gnu.org/licenses/               \n**/
/** Contact: https://github.com/PIK-LPJmL/LPJmL                                    \n**/
/**                                                                                \n**/
/**************************************************************************************/


#include "lpj.h"

void update_fast(Cell *cell,           /**< pointer to cell */
                 Dailyclimate climate, /**< subdaily climate data */
                 Real dt_fast,         /**< fast time step (s) */
                 int month,            /**< month (0..11) */
                 const Config *config  /**< LPj configuration  */
                )
{
#ifdef COUPLING_WITH_FMS
  Stand *stand;
  Pft *pft;
  Real beta;
  Real temp_bs;
  Real evap;
  Real heatflux_snow;
  Real melt;
  Real prec_energy;
  Real snowrunoff;
  Real soilwaterfactor;
  Real fpc_tree_stand;
  Real laketempn=0;
  Real groundflux_stand;
  int s,l,p;
  Real fracsum=0, soilw, gp_cell=0, canatemp_cell=0, soilw_cell=0, fpc_total_stand=0, fpc_total_stand_cell=0, soilt_cell=0,gc_cell=0,temp_laststep_cell=0,soilwaterfactor_cell=0, groundflux_cell=0;
  cell->albedo=0;
  cell->snowflux=0;
  foreachstand(stand,s,cell->standlist)
  {
    /* TODO: calculate real laketemperature not just depending on the airtemp. Right now laketemp is depending on airtemp and hence on soiltemp so we need to include water albedo in soiltemp calculation */
    beta=albedo_stand(stand);//*(1-cell->lakefrac-cell->ml.reservoirfrac)+c_albwater*(cell->lakefrac+cell->ml.reservoirfrac); 
    snowrunoff=snow(&stand->soil,&climate.prec,&melt,
                     climate.temp,climate.windspeed,cell->VPD2,climate.drag_q,climate.p_surf,cell->q_ca,&temp_bs,&evap,&heatflux_snow,dt_fast)*stand->frac;
    cell->output.msnowrunoff+=snowrunoff;
    climate.prec=max(climate.prec,0);
    stand->melt+=melt;
    stand->dprec+=climate.prec;
    cell->discharge.drunoff+=snowrunoff;
    cell->output.mevap+=evap*stand->frac; /* evap from snow runoff*/
    cell->snowflux+=(evap)*stand->frac/dt_fast;
    prec_energy = ((climate.temp-stand->soil.temp[TOPLAYER])*climate.prec*1e-3
                  +melt*1e-3*(T_zero-stand->soil.temp[TOPLAYER]))*c_water;
    stand->soil.perc_energy_lastday+=prec_energy;
#ifdef MICRO_HEATING
      /*THIS IS DEDICATED TO MICROBIOLOGICAL HEATING*/
      foreachsoillayer(l)
        stand->soil.micro_heating[l]=m_heat*stand->soil.decomC[l]/NSECONDSDAY*dt_fast;
      stand->soil.micro_heating[0]+=m_heat*stand->soil.litter.decomC/NSECONDSDAY*dt_fast;
#endif
/* TODO: calculate energy balance on lakes in the fast time step */
  /*   if (cell->lakefrac > 0)
     {
       laketemp(cell, &climate);
       //cell->laketemp=15;
       cell->output.mlaketemp+=cell->laketemp*ndaymonth1[month]/NSECONDSDAY*dt_fast;
     }
    else
    cell->output.mlaketemp=-1e32;//config->missing_value;
*/

//    cell->output.mq_ca += evap*stand->frac;
    
    soiltemp(&stand->soil,temp_bs,climate.t_flux, climate.dhdt, climate.drdt,cell->dedt,climate.swdown*(1-beta),climate.lwnet,melt,cell->evap1,evap,heatflux_snow,dt_fast,laketempn,FALSE,TRUE);
   /* stand->soil.temp[0]=max(stand->soil.temp[0],-80);
    stand->soil.temp2=max(stand->soil.temp2,-80);
    stand->soil.temp[0]=min(stand->soil.temp[0],80);
    stand->soil.temp2=min(stand->soil.temp2,80);*/
    if isnan(stand->soil.temp2)
      stand->soil.temp2=0;
     if isnan(stand->soil.temp[0])
      stand->soil.temp[0]=0;
    soilwaterfactor=0;
    foreachsoillayer(l)
      soilwaterfactor+=((stand->soil.w[l]*stand->soil.par->whcs[l]+stand->soil.w_fw[l])/(stand->soil.par->wsats[l]-stand->soil.par->wpwps[l]));
    soilwaterfactor/=NSOILLAYER;
    fpc_total_stand=0;
    foreachpft(pft,p,&stand->pftlist)
    {
       fpc_total_stand+=pft->fpc;
    }
    foreachsoillayer(l)
      stand->gtemp_soil[l]+=temp_response(stand->soil.temp[l])*dt_fast/NSECONDSDAY;
    foreachsoillayer(l)
      cell->output.msoiltemp[l]+=stand->soil.temp[l]*ndaymonth1[month]*stand->frac*(1.0/(1-stand->cell->lakefrac-stand->cell->ml.reservoirfrac))*dt_fast/NSECONDSDAY;
    soilw=0;
    foreachsoillayer(l)
      soilw+=(stand->soil.w[l]*stand->soil.par->whcs[l]+stand->soil.w_fw[l]);
    groundflux_stand=soilconduct(&stand->soil,0)*(stand->soil.temp2-stand->soil.temp[0])/soildepth[0]*1e3;
    fracsum+=stand->frac;
    groundflux_cell+=groundflux_stand*stand->frac;
    soilw_cell+=soilw*stand->frac;
    cell->albedo+=beta*stand->frac;
    gc_cell+=stand->gc*stand->frac;
    gp_cell+=stand->gp*stand->frac;
    soilwaterfactor_cell+=soilwaterfactor*stand->frac;
    temp_laststep_cell+=stand->soil.temp_laststep*stand->frac;
    fpc_total_stand=0;
    fpc_tree_stand=0;
    foreachpft(pft,p,&stand->pftlist)
    {
      fpc_total_stand+=pft->fpc;
      if(pft->par->type==TREE)
        fpc_tree_stand+=pft->fpc;
    //  fpc_total_stand_cell+=fpc_total_stand*stand->frac;
    }
    fpc_total_stand_cell+=fpc_total_stand*stand->frac;
    soilt_cell+=stand->soil.temp[0]*stand->frac;//+1*fpc_tree_stand)*stand->frac;   
    canatemp_cell+=stand->soil.temp2*stand->frac;

} /* of foreachstand */
 // if (stand->frac>0)
 //    cell->laketemp=soilt_cell;///stand->frac;
 // else
 //    cell->laketemp=cell->laketemp;
  cell->albedo+=c_albwater*(cell->lakefrac+cell->ml.reservoirfrac);
  cell->output.malbedo+=cell->albedo/NSECONDSDAY*dt_fast;
  soilt_cell+=cell->laketemp*(cell->lakefrac+cell->ml.reservoirfrac);
  canatemp_cell+=cell->laketemp*(cell->lakefrac+cell->ml.reservoirfrac);
  temp_laststep_cell+=cell->laketemp*(cell->lakefrac+cell->ml.reservoirfrac);
  if (fracsum>0)
  {
    groundflux_cell/=fracsum;
    fpc_total_stand_cell/=fracsum;
    gc_cell/=fracsum;
    gp_cell/=fracsum;
    soilwaterfactor_cell/=fracsum;
    soilw_cell/=fracsum;
  }
  else
  groundflux_cell=fpc_total_stand_cell=gc_cell=gp_cell=soilwaterfactor_cell=soilw_cell=0;
  /* canopy height humidity calculation (q_ca (kg/kg)) */
  humidity(cell, canatemp_cell, climate, gc_cell, temp_laststep_cell,
           soilwaterfactor_cell, soilw_cell,  groundflux_cell,
           dt_fast, config);
#endif
} /* of 'update_fast' */
