/**************************************************************************************/
/**                                                                                \n**/
/**                      q  s  a  t  .  c                                          \n**/
/**                                                                                \n**/
/**     C implementation of LPJmL                                                  \n**/
/**                                                                                \n**/
/**     Function calculates saturation water vapor pressure                        \n**/
/**                                                                                \n**/
/** (C) Potsdam Institute for Climate Impact Research (PIK), see COPYRIGHT file    \n**/
/** authors, and contributors see AUTHORS file                                     \n**/
/** This file is part of LPJmL and licensed under GNU AGPL Version 3               \n**/
/** or later. See LICENSE file or go to http://www.gnu.org/licenses/               \n**/
/** Contact: https://github.com/PIK-LPJmL/LPJmL                                    \n**/
/**                                                                                \n**/
/**************************************************************************************/

#include <stdio.h>
#include <math.h>
#include "types.h"
#include "date.h"
#include "numeric.h"
#include "units.h"


#define a -7.90298
#define b 5.02808
#define c -1.3816e-7
#define d 11.344
#define f 8.1328e-3
#define h 3.49149
#define Ts 373.16  /* water boiling point temperature in Kelvin Todo: dependend on altitude (pressure) */

/* calculate the saturation water vapor pressure in kPa */

Real qsat(Real temp, /**< temperature (deg C) */
          Real psurf /**< surface pressure (Pa) */
         )           /** \return saturation water vapor pressure (kPa) */
{

  //Real qsat1,qsat2,rdgas,rvgas,d622,d378;

/* calculation of boiling point denpending on pressure */
//pressure = psurf/3386; /* conversion into inHG */
//T
/* 
rdgas=287.04;
rvgas=461.50;

d622 = rdgas/rvgas;
d378 = 1-d622;


  Real psat,es;

  psat=610.78*exp(temp/(temp+238.3)*17.2694);

return 0.018*psat/(0.029*(psurf-psat));
*/

  if (temp>0)
    return 0.611 *exp((17.27*temp)/(temp+237.3));//273.15-29.65));
  else
    return exp(43.494-(6545.8/(temp+278)))/pow((temp+868),2)/1000;  /*A Simple Accurate Formula for Calculating Saturation Vapor
Pressure of Water and Ice, JIANHUA HUANG, 2017, Journal of applied Meteorology and climatology */
} /* of 'qsat' */
